---
name: Question
about: Ask a question, or prompt an update of the docs

---

## What is your question?

[write your question here, and answer the prompts below]

 - [ ] I found the freegenes-python documentation at https://vsoch.github.io/freegenes-python/
 - [ ] I found the freegenes documentation at https://vsoch.github.io/freegenes
 - [ ] The documentation does not answer my question

If the documentation doesn't answer your question, where do you think it would be appropriate to add (i.e., where did you go looking for it?)
